@@ -378,7 +378,8 @@ def read_rhi_profile(fname, labels=['50.0-percentile', '25.0-percentile',
                 )
             for i, row in enumerate(reader):
                 height[i] = float(row['Altitude [m MSL]'])
-                np_t[i] = int(row['N valid'])
+                if 'N valid' in row:
+                    np_t[i] = int(row['N valid'])
                 for j, label in enumerate(labels):
                     vals[i, j] = float(row[label])
 
@@ -455,7 +456,7 @@ def read_status(voltime, cfg, ind_rad=0):
     dayinfo = voltime.strftime('%y%j')
     timeinfo = voltime.strftime('%H%M')
     basename = 'ST'+cfg['RadarName'][ind_rad]+dayinfo
-    if cfg['path_convention'] == 'RT':
+    if cfg['path_convention'][ind_rad] == 'RT':
         datapath = cfg['datapath'][ind_rad]+'ST'+cfg['RadarName'][ind_rad]+'/'
     else:
         datapath = cfg['datapath'][ind_rad]+dayinfo+'/'+basename+'/'
